@@ -1,4 +1,5 @@
 import redis
+import six
 from aalam_common.config import cfg
 
 
@@ -10,7 +11,8 @@ def get_redis_obj():
     if not getattr(cfg.CONF, 'redis', None) or \
             not getattr(cfg.CONF.redis, 'url', None):
         return
-    return redis.StrictRedis.from_url(cfg.CONF.redis.url)
+    dr = False if six.PY2 else True
+    return redis.StrictRedis.from_url(cfg.CONF.redis.url, decode_responses=dr)
 
 
 redis_conn = get_redis_obj()
@@ -22,5 +24,5 @@ def redis_bgsave():
 
     try:
         redis_conn.bgsave()
-    except:
+    except Exception:
         pass
