@@ -635,16 +635,28 @@ class StaticsMiddleware(Middleware):
             fname if not fname_gz else fname_gz)
         response.cache_control = "no-cache"
         if not request.if_modified_since or \
-                response.last_modified > request.if_modified_since:
+                response.last_modified > request.if_modified_since or request.range:
             if not os.path.exists(fname):
                 return
 
             mime, enc = mimetypes.guess_type(fname)
             mime = mime or "application/octet-stream"
             response.content_type = mime
-            response.status_code = 200
-            with open(fname if not fname_gz else fname_gz, "rb") as fd:
-                response.body = fd.read()
+            if request.range:
+                st_info = os.stat(fname)
+                r_start, r_end = request.range.range_for_length(st_info.st_size)
+                response.status_code = 206
+                with open(fname, "rb") as fd:
+                    fd.seek(r_start)
+                    response.body = fd.read(
+                        r_end - r_start)
+                    response.content_range = webob.byterange.ContentRange(
+                        r_start, r_end,
+                        st_info.st_size)
+            else:
+                response.status_code = 200
+                with open(fname if not fname_gz else fname_gz, "rb") as fd:
+                    response.body = fd.read()
         else:
             response.status_code = 304
 
